summaryrefslogtreecommitdiff
path: root/i18npool
diff options
context:
space:
mode:
authorKarl Hong <khong@openoffice.org>2002-09-11 23:31:24 +0000
committerKarl Hong <khong@openoffice.org>2002-09-11 23:31:24 +0000
commit314587ecb62b02612bf2e1a548ec5521416b416e (patch)
treea83fbb8b3e1836a33e7ecb366fdc49ccc65c73ab /i18npool
parent355a94d68773194d3f1825999739a82d6f03eef8 (diff)
#102975# set non-break space as weak char.
Diffstat (limited to 'i18npool')
-rw-r--r--i18npool/source/breakiterator/breakiteratorImpl.cxx8
1 files changed, 4 insertions, 4 deletions
diff --git a/i18npool/source/breakiterator/breakiteratorImpl.cxx b/i18npool/source/breakiterator/breakiteratorImpl.cxx
index ed90a2dce906..a6f5dae7819e 100644
--- a/i18npool/source/breakiterator/breakiteratorImpl.cxx
+++ b/i18npool/source/breakiterator/breakiteratorImpl.cxx
@@ -2,9 +2,9 @@
*
* $RCSfile: breakiteratorImpl.cxx,v $
*
- * $Revision: 1.6 $
+ * $Revision: 1.7 $
*
- * last change: $Author: khong $ $Date: 2002-09-05 18:04:24 $
+ * last change: $Author: khong $ $Date: 2002-09-12 00:31:24 $
*
* The Contents of this file are made available subject to the terms of
* either of the following licenses
@@ -394,8 +394,8 @@ sal_Int16 BreakIteratorImpl::getScriptClass(sal_Unicode currentChar )
//JP 21.9.2001: handle specific characters - always as weak
// definition of 1 - this breaks a word
// 2 - this can be inside a word
- // 0x20 - Bug 102975, declare western blank as WEAK char.
- if( 1 == currentChar || 2 == currentChar || 0x20 == currentChar )
+ // 0x20 & 0xA0 - Bug 102975, declare western space and non-break space as WEAK char.
+ if( 1 == currentChar || 2 == currentChar || 0x20 == currentChar || 0xA0 == currentChar)
nRet = ScriptType::WEAK;
else
nRet = unicode::getUnicodeScriptType( currentChar, typeList, ScriptType::WEAK );